@@ -65,6 +65,7 @@ FRONT_CONFIGDIR = '/etc/mw-proxy'
 FRONT_LISTEN_HOST = None  # IP address to bind to
 FRONT_LISTEN_PORT = None  # port number to bind to
 FRONT_LISTEN_SSL = None   # Listen as SSL socket (True/False)
+FRONT_LISTEN_TLSv1_2 = True # Newer TLS version requiring Python 2.7.9 at least
 FRONT_KEY = None          # SSL private key
 FRONT_CERT = None         # SSL certificate
 FRONT_CACERT = None       # SSL CA certificate
@@ -213,8 +214,10 @@ def create_listener(host,port):
   sock = socket.socket()
   sock.setsockopt(socket.SOL_SOCKET,socket.SO_REUSEADDR,1)
   if FRONT_LISTEN_SSL:
-#   ctx = SSL.Context(SSL.TLSv1_METHOD)
-    ctx = SSL.Context(SSL.TLSv1_2_METHOD)
+    if FRONT_LISTEN_TLSv1_2:
+      ctx = SSL.Context(SSL.TLSv1_2_METHOD)
+    else:
+      ctx = SSL.Context(SSL.TLSv1_METHOD)
     ctx.use_privatekey_file (os.path.join(FRONT_CONFIGDIR,FRONT_KEY))
     ctx.use_certificate_file(os.path.join(FRONT_CONFIGDIR,FRONT_CERT))
     if FRONT_CACERT != None:
